import { Directive, ElementRef, forwardRef, HostListener, Inject, NgModule } from '@angular/core';
import { FormsModule, NG_VALUE_ACCESSOR } from '@angular/forms';
import { registerElement, BaseValueAccessor } from '@nativescript/angular';
function convertToInt(value) {
    let normalizedValue;
    if (value === undefined || value === null) {
        normalizedValue = 0;
    }
    else {
        if (typeof value === 'number') {
            normalizedValue = value;
        }
        else {
            const parsedValue = parseInt(value.toString(), 10);
            normalizedValue = isNaN(parsedValue) ? 0 : parsedValue;
        }
    }
    return Math.round(normalizedValue);
}
registerElement('CheckBox', () => require('../checkbox').CheckBox);
const CHECKED_VALUE_ACCESSOR = {
    provide: NG_VALUE_ACCESSOR,
    useExisting: forwardRef(() => CheckedValueAccessor),
    multi: true
};
let CheckedValueAccessor = class CheckedValueAccessor extends BaseValueAccessor {
    constructor(elementRef) {
        super(elementRef.nativeElement);
        this.onTouched = () => { };
    }
    checkedChangeListener(event) {
        this.onChange(event.value);
    }
    writeValue(value) {
        this.view.checked = value;
    }
    registerOnTouched(fn) {
        this.onTouched = fn;
    }
};
__decorate([
    HostListener('checkedChange', ['$event'])
], CheckedValueAccessor.prototype, "checkedChangeListener", null);
CheckedValueAccessor = __decorate([
    Directive({
        selector: 'CheckBox[ngModel], CheckBox[formControlName], CheckBox[formControl], checkBox[ngModel], checkBox[formControlName], checkBox[formControl], check-box[ngModel], check-box[formControlName], check-box[formControl]',
        providers: [CHECKED_VALUE_ACCESSOR]
    }),
    __param(0, Inject(ElementRef))
], CheckedValueAccessor);
export { CheckedValueAccessor };
let TNSCheckBoxModule = class TNSCheckBoxModule {
};
TNSCheckBoxModule = __decorate([
    NgModule({
        declarations: [CheckedValueAccessor],
        providers: [],
        imports: [FormsModule],
        exports: [FormsModule, CheckedValueAccessor]
    })
], TNSCheckBoxModule);
export { TNSCheckBoxModule };
//# sourceMappingURL=index.js.map